<p align="center">
<a href="https://github.com/acaire/finders/actions"><img alt="Actions Status" src="https://github.com/acaire/finders/workflows/Test/badge.svg"></a>
<a href="https://github.com/acaire/finders/blob/master/LICENSE"><img alt="License: MIT" src="https://img.shields.io/github/license/acaire/finders"></a>
<a href="https://pypi.org/project/finders/"><img alt="PyPI" src="https://img.shields.io/pypi/v/finders"></a>
</p>

finders
=======

Find resources to determine if you want to keep them
